#!/bin/bash

PACKAGE_NAME=ite

name=${0##*/}
BUILD_ROOT=${0%usr/share/ite/$name}
if [ "$BUILD_ROOT" == '/' ]; then
    echo 1>&2 The RPM package should be built in a SUBDIRECTORY.
    exit 1
fi
[ "$BUILD_ROOT" == "${BUILD_ROOT#/}" ] && BUILD_ROOT="`pwd`/$BUILD_ROOT"

SPEC_FILE=/tmp/buildrpm.$$.spec

if [ ! -d /$BUILD_ROOT ]; then
    echo 1>&2 "error: directory /$BUILD_ROOT does not exist."
    exit 2
fi

trap "rm -f $SPEC_FILE; exit" 0 1 2 3 15

cat <<END >$SPEC_FILE
%define ver	0.2
%define rel	5

Name:		$PACKAGE_NAME
Buildroot: 	$BUILD_ROOT
Requires:	vim-enhanced >= 6.0 vim-X11 >= 6.0 tetex tetex-latex
Requires:	xdvik >= 22.74.1 aspell >= 0.33
Requires:	gawk grep sed
Provides:	ite
Version: 	%ver
Release:	%rel
Summary:	Integrated TeX Environments
Group:		Applications/Publishing
URL:		ftp://ftp.cc.ac.cn/pub/cct/ite
Packager:	Zhang Lin-bo <zlb@lsec.cc.ac.cn>
License:	non-commercial use

%description

This package provides an integrated TeX environment based on gvim
and basic CTeX support for Kile.

GVIM support:

    A shell script 'vtex' is provided to start gvim as an integrated
    TeX environment with a set of toolbar buttons for processing and
    previewing a LaTeX document. Forward and inverse source search
    are fully supported (requiring teTeX 2.0.2).

Kile support:

    Two shell scripts are provided.

    - kdvi, which is a symbolic link to kdvi-wrapper, is used to replace
      KDE's kdvi script for forward search.

    - kile-xdvik, is called by xdvik to return to the source document
      (inverse search).

Refer to the last section of ftp://ftp.cc.ac.cn/pub/cct/README.pdf
for more information.
  
%prep

%build

%install

%post

VIMRT=\`env LANG=C /usr/bin/vim --version 2>&1 | grep 'system vimrc file:' | \
	awk -F\" '{print \$2}' | sed -e 's/\/macros\/vimrc$//g'\`
if test -z "\$VIMRT"; then
    echo 1>&2 "Error: cannot determine VIM scripts directory."
    exit 1
fi

(
    mkdir -p \$VIMRT/syntax
    cd \$VIMRT/syntax; ln -sf /usr/share/ite/syntax/cct.vim .
    mkdir -p \$VIMRT/bitmaps
    cd \$VIMRT/bitmaps; ln -sf /usr/share/ite/pixmaps/*.xpm .
)

if test -r /usr/bin/kdvi && ! grep -q "kdvi-wrapper" /usr/bin/kdvi; then
    echo 1>&2 "Saving /usr/bin/kdvi as /usr/bin/kdvi.save"
    /bin/mv -f /usr/bin/kdvi /usr/bin/kdvi.save
fi
/bin/rm -f /usr/bin/kdvi
ln -s kdvi-wrapper /usr/bin/kdvi

aspell create master /usr/share/ite/spell.dic < /usr/share/ite/spell.words

%postun

if [ ! -r /usr/bin/kdvi ]; then
    /bin/rm -f /usr/bin/kdvi
    if test -f /usr/bin/kdvi.save; then
	echo 1>&2 "Restoring /usr/bin/kdvi.save as /usr/bin/kdvi"
	/bin/mv /usr/bin/kdvi.save /usr/bin/kdvi
    fi
fi

for f in /usr/share/vim/vim*/syntax/cct.vim /usr/share/vim/vim*/bitmaps/*.xpm
do
    test -r \$f || rm -f \$f
done
rmdir --ignore-fail-on-non-empty /usr/share/vim/vim*/bitmaps \
	/usr/share/vim/vim*/syntax

%files
/usr/bin/kdvi-wrapper
/usr/bin/kile-xdvik
/usr/bin/vtex
/usr/share/ite/buildrpm.sh
/usr/share/ite/kile.txt
/usr/share/ite/pixmaps/Clean.xpm
/usr/share/ite/pixmaps/CTeX.xpm
/usr/share/ite/pixmaps/Empty.xpm
/usr/share/ite/pixmaps/Empty1.xpm
/usr/share/ite/pixmaps/Log.xpm
/usr/share/ite/pixmaps/Master.xpm
/usr/share/ite/pixmaps/Quick.xpm
/usr/share/ite/pixmaps/Search.xpm
/usr/share/ite/pixmaps/Spell.xpm
/usr/share/ite/pixmaps/XDvi.xpm
/usr/share/ite/spell.dic
/usr/share/ite/spell.words
/usr/share/ite/spell.sh
/usr/share/ite/syntax/cct.vim
/usr/share/ite/vtex.vim
/usr/share/ite/xpm.c

%changelog

* Wed Jun 04 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- keep current LC_CTYPE setting (it seems that gvim works well with the
  zh_CN.GB18030 locale, not as vim).

- added toolbar button for spelling check

* Tue Jun 03 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- syntax hilighting for \verb* and {verbatim*} (bug in tex.vim)

* Mon Jun 02 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- removed dependency on CCT and use 'latex' instead of 'ctex' if the latter
  is not available.

- set tw=78, language=cn-euc and add 'tcqmM' to 'formatoptions'

END

rpmbuild -bb $SPEC_FILE
