#!/bin/bash

export LC_ALL=C
export LANG==C

# `grep -v "$rexp"' can be used to filter GBK chars
###ECHO="/bin/echo -e"
###rexp="[`$ECHO '\200'`-`$ECHO '\376'`][`$ECHO '\080'`-`$ECHO '\376'`]"

# Check for existence of local dictionary
DIC="--add-extra-dicts=/usr/share/ite/spell.dic"
if [ -r ${HOME}/.ite/spell.words ]; then
    if [ ${HOME}/.ite/spell.words -nt ${HOME}/.ite/spell.dic ]; then
	aspell create master ${HOME}/.ite/spell.dic < ${HOME}/.ite/spell.words
    fi
    DIC="${DIC},${HOME}/.ite/spell.dic"
fi

#
# Note: words in [...] and |...| (frequently used with shortvrb package)
#	are ignored.
#
# awk is used to filter multiple-line blocks like $ ... $, $$ ... $$,
# \begin{verbatim} ... \end{verbatim}, etc.
#
# Note: don't filter \begin{comment} ... \end{comment},
#	it's contents should be checked!!!
#

VIMFILE=`mktemp /tmp/itespell.vim.XXXXXX`
LSTFILE=`mktemp /tmp/itespell.lst.XXXXXX`
#
# SYNTAX_HIGHLIGHT == 0 ==> define search patterns for erroneour words
export SYNTAX_HIGHLIGHT=0

trap "/bin/rm -f $LSTFILE" 0 1 2 3 15

cat $1 | \
    awk '{print gensub(/[\200-\376][\080-\377]/, " ", "g")}' | \
    sed -e 's/\[.*\]/ /g' -e 's/|.*|/ /g' \
	-e 's/\\verb\*\(.\).*\1/ /g' \
	-e 's/\\verb\([^:alpha:]\).*\1/ /g' \
	-e 's/\\begin[{]verbatim[}].*\\end[{]verbatim[}]/ /g' \
	-e 's/\\begin[{]verbatim\*[}].*\\end[{]verbatim\*[}]/ /g' \
	\
	-e 's/\\begin[{]math[}].*\\end[{]math[}]/ /g' \
	-e 's/\$.\+\$/ /g' -e 's/\\[(].*\\[)]/ /g'  \
	-e 's/\$\$.*\$\$/ /g'  -e 's/\\\[.*\\\]/ /g' \
	-e 's/\\begin[{]equation[}].*\\end[{]equation[}]/ /g' \
	-e 's/\\begin[{]displaymath[}].*\\end[{]displaymath[}]/ /g' \
	-e 's/\\begin[{]eqnarray[}].*\\end[{]eqnarray[}]/ /g' \
	-e 's/\\begin[{]eqnarray\*[}].*\\end[{]eqnarray\*[}]/ /g' \
	-e 's/\\begin[{]gather[}].*\\end[{]gather[}]/ /g' \
	-e 's/\\begin[{]gather\*[}].*\\end[{]gather\*[}]/ /g' \
	-e 's/\\begin[{]multline[}].*\\end[{]multline[}]/ /g' \
	-e 's/\\begin[{]multline\*[}].*\\end[{]multline\*[}]/ /g' \
	-e 's/\\begin[{]align[}].*\\end[{]align[}]/ /g' \
	-e 's/\\begin[{]align\*[}].*\\end[{]align\*[}]/ /g' \
	-e 's/\\begin[{]flalign[}].*\\end[{]flalign[}]/ /g' \
	-e 's/\\begin[{]flalign\*[}].*\\end[{]flalign\*[}]/ /g' \
	-e 's/\\begin[{]alignat[}].*\\end[{]alignat[}]/ /g' \
	-e 's/\\begin[{]alignat\*[}].*\\end[{]alignat\*[}]/ /g' \
	| \
    awk '
	#
	# Note: blocks within one line should be filtered through sed!

	function check_skip(start, end,    i)
	{
	    if ((i=index($0, start)) > 0) {
		skipend = end
		if (i > 1) print substr($0, 1, i - 1)
		next
	    }
	}

	BEGIN {
	    skipend = ""
	}
	
	{
	    if (skipend != "") {
		if ((i = index($0, skipend)) > 0) {
		    print substr($0, i + length(skipend))
		    skipend = ""
		}
		next
	    }

	    check_skip("\\begin{verbatim}", "\\end{verbatim}")
	    check_skip("\\begin{verbatim*}", "\\end{verbatim*}")
	    check_skip("$$", "$$")
	    check_skip("$", "$")
	    check_skip("\\(", "\\)")
	    check_skip("\\[", "\\]")
	    check_skip("\\begin{math}", "\\end{math}")
	    check_skip("\\begin{displaymath}", "\\end{displaymath}")
	    check_skip("\\begin{equation}", "\\end{equation}")
	    check_skip("\\begin{eqnarray}", "\\end{eqnarray}")
	    check_skip("\\begin{eqnarray*}", "\\end{eqnarray*}")
	    check_skip("\\begin{gather}", "\\end{gather}")
	    check_skip("\\begin{gather*}", "\\end{gather*}")
	    check_skip("\\begin{multline}", "\\end{multline}")
	    check_skip("\\begin{multline*}", "\\end{multline*}")
	    check_skip("\\begin{align}", "\\end{align}")
	    check_skip("\\begin{align*}", "\\end{align*}")
	    check_skip("\\begin{flalign}", "\\end{flalign}")
	    check_skip("\\begin{flalign*}", "\\end{flalign*}")
	    check_skip("\\begin{alignat}", "\\end{alignat}")
	    check_skip("\\begin{alignat*}", "\\end{alignat*}")

	    print
	}
	' | \
    aspell -l --mode=tex $DIC | sort -u | tee $LSTFILE | \
    awk '
	BEGIN {
	    syntax_hl = ENVIRON["SYNTAX_HIGHLIGHT"]

	    if (syntax_hl != 0) {
		printf "syntax clear\n"
	    } else {
		first_call = 1
	    }
	}

	{
	    if (syntax_hl != 0) {
		printf "syntax match SpellErrors \"\\<%s\\>\"\n", $0
	    } else if (first_call != 0) {
		printf "let s:pattern = \"\\\\<%s\\\\>\"\n", $0
		first_call = 0
	    } else {
		printf "let s:pattern = s:pattern . \"\\\\|\\\\<%s\\\\>\"\n",$0
	    }
	}

	END {
	    if (syntax_hl != 0) {
		#printf "highlight link SpellErrors ErrorMsg\n\n" ;
		printf "highlight SpellErrors guifg=white guibg=red\n\n" ;
	    } else {
		printf "let @/ = s:pattern\n"
	    }
	}
	' >$VIMFILE

if test -s $LSTFILE; then
    if [ "$SYNTAX_HIGHLIGHT" != "0" ]; then
	cat <<END >> $VIMFILE
	    echo "    "
	    echo "*****************************************************"
	    echo " ƴдøʾҲ, 󵥴г"
	    echo " ƴдĴ ':edit' ָʾ"
	    echo "*****************************************************"
	    echo "    "
END
    else
	cat <<END >> $VIMFILE
	    echo "    "
	    echo "*****************************************************"
	    echo " 󵥴രг, Ҳരڡ󵥴ѱ"
	    echo " óɵǰͼ, Ĵ \\"/<س>\\" ҡ"
	    echo "*****************************************************"
	    echo "    "
END
    fi

    /bin/rm -f ${1}.err
    if /bin/cp -f $LSTFILE ${1}.err; then
	echo "15vsplit +e! ${1}.err" >> $VIMFILE
	echo "set readonly" >> $VIMFILE
    fi
else
    cat <<END > $VIMFILE
	echo "    "
	echo "****************"
	echo " ûƴд"
	echo "****************"
	echo "    "
END
fi

echo "let dummy = system(\"/bin/rm -f $VIMFILE\")" >> $VIMFILE

echo $VIMFILE
