/* This program turns 

gcc -Wall -o xpm xpm.c -L/usr/X11R6/lib -lXpm -lX11 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <strings.h>
#include <X11/xpm.h>

int main(int argc, char *argv[])
{
    XpmImage image;
    XpmInfo  info;
    unsigned int *data, *p, *q;
    int i, j, matte, bg;

    if (argc != 2) {
	fprintf(stderr, "Usage: xpm file.xpm\n");
	exit(1);
    }

    fprintf(stderr, "Reading image from \"%s\" ...\n", argv[1]);
    if ((i = XpmReadFileToXpmImage(argv[1], &image, &info)) != 0) {
	fprintf(stderr, "Cannot read XPM file %s, ret = %d\n", argv[1], i);
	exit(1);
    }

    fprintf(stderr, "width = %d, height = %d, cpp = %d\n",
		image.width, image.height, image.cpp);

#if 1
    matte = 0;
    bg = 1;
#else
    /* Find backgroud and matte color index */
    fprintf(stderr, "ncolors = %d\n", image.ncolors);
    matte = -1;
    bg = -1;
    for (i = 0; i < image.ncolors; i++) {
#if 0
	fprintf(stderr, "color %d, string='%s', color='%s'\n",
		i, image.colorTable[i].string, image.colorTable[i].c_color);
#endif
	if (!strcasecmp(image.colorTable[i].c_color, "None"))
		matte = i;
	if (!strcasecmp(image.colorTable[i].c_color, "#FFFFFF"))
		bg = i;
    }
    if (matte == -1) {
	fprintf(stderr, "Cannot determine matte color index.\n");
	exit(1);
    }
    if (bg == -1) {
	fprintf(stderr, "Cannot determine background color index.\n");
	exit(1);
    }
#endif

    data = malloc(image.width * image.height * sizeof(*image.data));
    memcpy(data, image.data, image.width * image.height * sizeof(*image.data));

    p = data;
    q = image.data;
    for (j = 0; j < image.height; j++)
	for (i = 0; i < image.width; i++, p++, q++) {
	    if (*p != bg) continue;
	    if ((i > 0			&& *(p - 1)           != bg) ||
		(i < image.width - 1	&& *(p + 1)           != bg) ||
		(j > 0			&& *(p - image.width) != bg) ||
		(j < image.height - 1	&& *(p + image.width) != bg))
		continue;
	    *q = matte;
	}

    fprintf(stderr, "Writing new image to \"%s\" ...\n", argv[1]);
    if ((i = XpmWriteFileFromXpmImage(argv[1], &image, &info)) != 0) {
	fprintf(stderr, "Cannot write XPM file %s, ret = %d\n", argv[1], i);
	exit(1);
    }

    return 0;
}
